@@ -19,7 +19,8 @@ sub run {
     my $pool = SVN::Pool->new_default;
     for my $target (@arg) {
 	$pool->clear;
-	$target->as_depotpath ($self->{rev});
+	$target->as_depotpath(
+            $self->resolve_revision($target,$self->{rev}));
 	my $root = $target->root ($self->{xd});
 	my $stream = $root->file_contents ($target->{path});
 	# XXX: the keyword layer interface should also have reverse
